@@ -26,19 +26,28 @@ def parse_args():
         "chef-file-dest": "/tmp/chef",
     }
 
-    try:
-        config_path = os.environ.get('CUP_CONFIG_PATH', os.path.join(os.path.realpath(os.getcwd()), 'chef-solo-cup.json'))
-        with open(config_path) as f:
-            config = json.loads(f.read())
-    except IOError:
-        config = {}
+    paths = [
+        os.path.join(os.path.realpath(os.getcwd()), 'chef-solo-cup.json'),
+        os.path.join(os.path.realpath(os.getcwd()), '.chef', 'chef-solo-cup.json'),
+        os.path.join(os.path.realpath(os.getcwd()), '.chef', 'user-chef-solo-cup.json')
+    ]
+
+    config = {}
+    for path in paths:
+        try:
+            with open(path) as f:
+                data = json.loads(f.read())
+                config = dict(config.items() + data.items())
+                break
+        except IOError:
+            pass
 
     options = dict(defaults.items() + config.items())
 
     parser = argparse.ArgumentParser(description='Chef-solo-cup, a chef-solo wrapper',
                                      epilog="Chef Solo Cup is pwnage",
                                      formatter_class=argparse.RawDescriptionHelpFormatter)
-    parser.add_argument('command', help='command to run', choices=['bootstrap', 'clean', 'default', 'gem', 'ruby', 'run', 'sync', 'sudo', 'test', 'update'])
+    parser.add_argument('command', help='command to run', choices=['bootstrap', 'clean', 'default', 'gem', 'ruby', 'run', 'sync', 'sudo', 'test', 'update'], nargs='?')
     parser.add_argument('-c', '--command', help='command to run', default=options['command'], dest='cmd')
     parser.add_argument('-C', '--config-path', help='relative path from chef file destination to solo config file', default=options['config-path'], dest='config_path')
     parser.add_argument('-d', '--dna-patterns', help='space-separated list of patterns to match against dna file names', default=options['dna-patterns'], dest='dna_patterns', nargs='+')
